# Generated by roxygen2: do not edit by hand

S3method(print,orisma_dict)
S3method(print,orisma_dims)
S3method(print,orisma_kappa)
S3method(print,orisma_matrix)
S3method(print,orisma_normativa)
S3method(print,orisma_priority)
S3method(print,orisma_ranking)
S3method(print,orisma_result)
export(orm_analyse)
export(orm_ass)
export(orm_ass_plot)
export(orm_autodim)
export(orm_bridge)
export(orm_dedup)
export(orm_dict)
export(orm_dict_add_category)
export(orm_dict_add_terms)
export(orm_dict_categories)
export(orm_dict_list)
export(orm_dim_matrix)
export(orm_extract)
export(orm_extraction_matrix)
export(orm_load)
export(orm_normativa)
export(orm_priority)
export(orm_ranking)
export(orm_relevance_guard)
export(orm_report)
export(orm_risk_sheet)
export(orm_run)
export(orm_run_guarded)
export(orm_validate)
importFrom(cli,cli_alert_danger)
importFrom(cli,cli_alert_info)
importFrom(cli,cli_alert_success)
importFrom(cli,cli_alert_warning)
importFrom(cli,cli_h1)
importFrom(cli,cli_h2)
importFrom(cli,cli_progress_bar)
importFrom(cli,cli_progress_done)
importFrom(cli,cli_progress_update)
importFrom(cli,cli_rule)
importFrom(digest,digest)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,as_tibble)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,case_when)
importFrom(dplyr,everything)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,row_number)
importFrom(dplyr,select)
importFrom(dplyr,starts_with)
importFrom(dplyr,summarise)
importFrom(dplyr,ungroup)
importFrom(ggplot2,aes)
importFrom(ggplot2,annotate)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,geom_col)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggsave)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_colour_gradient)
importFrom(ggplot2,scale_colour_manual)
importFrom(ggplot2,scale_fill_gradient)
importFrom(ggplot2,scale_size_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(ggrepel,geom_text_repel)
importFrom(glue,glue)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.off)
importFrom(grDevices,png)
importFrom(jsonlite,read_json)
importFrom(jsonlite,write_json)
importFrom(magrittr,"%>%")
importFrom(readr,read_csv)
importFrom(readr,write_csv)
importFrom(stats,na.omit)
importFrom(stats,reorder)
importFrom(stats,setNames)
importFrom(stringr,str_escape)
importFrom(stringr,str_extract)
importFrom(tidyr,pivot_longer)
importFrom(tools,file_ext)
importFrom(utils,head)
importFrom(utils,packageVersion)
