% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/orm_dict.R
\name{orm_dict_add_category}
\alias{orm_dict_add_category}
\title{Add a new risk category to a dictionary}
\usage{
orm_dict_add_category(
  dict,
  key,
  label_en,
  label_es,
  terms,
  worker_exposure_terms = character(0),
  taxonomy = "user",
  block = "G - Custom"
)
}
\arguments{
\item{dict}{An \code{orisma_dict} object.}

\item{key}{Character. Short identifier (no spaces).}

\item{label_en}{Character. Category name in English.}

\item{label_es}{Character. Category name in Spanish.}

\item{terms}{Character vector. Search terms.}

\item{worker_exposure_terms}{Character vector. Worker exposure indicators.}

\item{taxonomy}{Character. Source taxonomy label.}

\item{block}{Character. Block label (e.g. "A - Safety").}
}
\value{
Updated \code{orisma_dict}.
}
\description{
Add a new risk category to a dictionary
}
